documentationtools.ClassCrawler
===============================

.. abjad-lineage:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler

.. autoclass:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.code_root
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.include_private_objects
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.module_crawler
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.root_package_name
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__call__
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__eq__
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__format__
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__ne__
      ~abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.code_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.include_private_objects
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.module_crawler
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.root_package_name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.__repr__
   :noindex:
